# Xilinx Boards

The {py:mod}`torii_boards.xilinx` module provides a collection of Xilinx FPGA development boards, they are based off the Torii {py:class}`XilinxPlatform <torii.platform.vendor.xilinx.XilinxPlatform>` platform and support the [ISE], [Vivado], and [Symbiflow] toolchains.

```{toctree}
:maxdepth: 2
artix7
kintex7
spartan7
zynq7
kintex_us
spartan6
spartan3
```

[ISE]:　https://www.xilinx.com/products/design-tools/ise-design-suite.html
[Vivado]:　https://www.xilinx.com/products/design-tools/vivado.html
[Symbiflow]:　https://f4pga.readthedocs.io/projects/prjxray/en/latest/
